@@ -174,7 +174,7 @@ render_book = function(
   } else {
     render_cur_session(files, main, config, output_format, clean, envir, ...)
   }
-  if (!xfun::isFALSE(delete_main)) file.remove(main)
+  if (!isFALSE(delete_main)) file.remove(main)
   res
 }
 
